Struct amazon_sp_fulfillment_inbound::models::asin_prep_instructions::AsinPrepInstructions
source · [−]pub struct AsinPrepInstructions {
pub ASIN: Option<String>,
pub barcode_instruction: Option<BarcodeInstruction>,
pub prep_guidance: Option<PrepGuidance>,
pub prep_instruction_list: Option<Vec<PrepInstruction>>,
}Expand description
AsinPrepInstructions : Item preparation instructions to help with item sourcing decisions.
Fields
ASIN: Option<String>The Amazon Standard Identification Number (ASIN) of the item.
barcode_instruction: Option<BarcodeInstruction>prep_guidance: Option<PrepGuidance>prep_instruction_list: Option<Vec<PrepInstruction>>A list of preparation instructions to help with item sourcing decisions.
Implementations
sourceimpl AsinPrepInstructions
impl AsinPrepInstructions
sourcepub fn new() -> AsinPrepInstructions
pub fn new() -> AsinPrepInstructions
Item preparation instructions to help with item sourcing decisions.